>From 33398472f7149cdd393cd89548e834bfb1835452 Mon Sep 17 00:00:00 2001
From: Craig Ringer <craig@2ndquadrant.com>
Date: Thu, 19 Jun 2014 13:56:57 +0800
Subject: [PATCH 2/2] Fix use of server-queried version before connection

psqlODBC attempted to use the version that's queried from the server before it
was obtained from the server during the connection setup. Because the server
version is initialized to 0.0, tests for "server version >= 7.4" or "server
version >= 6.4" using the PG_VERSION_LT macro were always returning false.

Instead, use PROTOCOL_64 and PROTOCOL_74 tests against conninfo. These don't
offer any "greater than" form, so just test both. There's little point adding
anything prettier when it can all be removed when v1/v2 protocol support is
removed soon anyway.

The issue mentioned in the commit:

Fix FE/BE protocol loss of sync due to invalid empty query

was caused by this problem.
---
 connection.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/connection.c b/connection.c
index f33a6a4..7162076 100644
--- a/connection.c
+++ b/connection.c
@@ -2747,7 +2747,7 @@ CC_send_query_append(ConnectionClass *self, const char *query, QueryInfo *qi, UD
 				empty_reqs;
 	BOOL		ReadyToReturn = FALSE,
 				query_completed = FALSE,
-				beforeV2 = PG_VERSION_LT(self, 6.4),
+				beforeV2 = !(PROTOCOL_64(&self->connInfo) || PROTOCOL_74(&self->connInfo)),
 				aborted = FALSE,
 				used_passed_result_object = FALSE,
 			discard_next_begin = FALSE,
-- 
1.9.0

